Thread

Struct Thread 

pub struct Thread(pub UnsafeCell<k_thread>);
A zephyr thread.

This declares a single k_thread in Zephyr.

Tuple Fields

0: UnsafeCell<k_thread>

Implementations

Source

impl Thread

pub const unsafe fn new() -> Self

Static allocation of a thread

This makes the zero-initialized memory that can later be used as a thread.

Safety

The caller is responsible for using operations such as create to construct the thread, according to the underlying semantics of the Zephyr operations.